@@ -4,7 +4,7 @@ methods that act upon a transfer function to gain functions such as the
 mass function.
 '''
 
-version = '1.1.9'
+version = '1.1.10'
 
 ###############################################################################
 # Some Imports
@@ -15,7 +15,7 @@ import numpy as np
 from numpy import sin, cos, tan, abs, arctan, arccos, arcsin, exp
 
 # from scitools.std import sin,cos,tan,abs,arctan,arccos,arcsin #Must be in this form to work for some reason.
-
+from cosmolopy import distance as cd
 import cosmography
 import tools
 from fitting_functions import fits
@@ -141,7 +141,7 @@ class Perturbations(object):
                        reion__fraction :: -1
                        reion__delta_redshift :: 1.5
                        Scalar_initial_condition :: 1
-                       scalar_amp      :: 1
+                       scalar_amp      :: 1E-9
                        scalar_running  :: 0
                        tensor_index    :: 0
                        tensor_ratio    :: 1
@@ -160,7 +160,6 @@ class Perturbations(object):
                        transfer__k_per_logint :: 11
                        transfer__kmax :: 0.25
                                 
-
     """
 
 
@@ -170,7 +169,7 @@ class Perturbations(object):
                  z=0.0,
                  wdm_mass=None, k_bounds=[0.0000001, 20000.0],
                  delta_halo=200.0, delta_wrt='mean', user_fit='', transfer_fit='CAMB',
-                 cut_fit=True, ** kwargs):
+                 cut_fit=True, z2=None, nz=None, ** kwargs):
         """
         Initializes the cosmology for which to perform the perturbation analysis.      
         """
@@ -201,7 +200,7 @@ class Perturbations(object):
                                  'reion__fraction' :-1,
                                  'reion__delta_redshift' : 1.5,
                                  'Scalar_initial_condition' : 1,
-                                 'scalar_amp'      : 1,
+                                 'scalar_amp'      : 1E-9,
                                  'scalar_running'  : 0,
                                  'tensor_index'    : 0,
                                  'tensor_ratio'    : 1,
@@ -215,7 +214,8 @@ class Perturbations(object):
                                  'w_perturb'      : False,
                                  'DoLensing'       : False,
                                  'transfer__k_per_logint': 11,
-                                 'transfer__kmax':0.25}
+                                 'transfer__kmax':0.25,
+                                 'ThreadNum':0}
 
 
         #A list of available HMF fitting functions and their identifiers
@@ -223,9 +223,25 @@ class Perturbations(object):
                         "Watson_FoF", "Watson", "Crocce", "Courtin", "Bhattacharya", "Behroozi", "user_model",
                         "Peacock"]
 
+        #Set all given parameters -- annoying but has to be done for best updating
+        self.M = M
+        self.mf_fit = mf_fit
+        self.k_bounds = k_bounds
+        self._transfer_file = transfer_file
+        self.wdm_mass = wdm_mass
+        self._delta_halo_base = delta_halo
+        self.delta_wrt = delta_wrt
+        self.user_fit = user_fit
+        self.z = z
+        self.transfer_fit = transfer_fit
+        self.cut_fit = cut_fit
+        self.z2 = z2
+        self.nz = nz
+
+        #Now update them all
         self.update(M=M, mf_fit=mf_fit, k_bounds=k_bounds, transfer_file=transfer_file, wdm_mass=wdm_mass,
                      delta_halo=delta_halo, delta_wrt=delta_wrt, user_fit=user_fit, z=z,
-                     transfer_fit=transfer_fit, cut_fit=cut_fit, ** kwargs)
+                     transfer_fit=transfer_fit, cut_fit=cut_fit, z2=z2, nz=nz, ** kwargs)
 
     def update(self, **kwargs):
         """
@@ -235,66 +251,91 @@ class Perturbations(object):
         #First update the basic dictionaries
         for key, val in kwargs.iteritems():
             if key in self._transfer_cosmo:
-                self._transfer_cosmo.update({key:val})
-                del self.cosmo_params
-                del self.camb_params
+                if self._transfer_cosmo[key] != val:
+                    if key is 'omegab':
+                        #this parameter directly affects more than just TF
+                        del self._power_cdm_0
+                        del self._sigma_0
+                        del self._dlnsdlnm
+                        del self.dndm
+                    elif key is 'omegac':
+                        #this parameter directly affects more than just TF
+                        del self._power_cdm_0
+                        del self._power_0
+                        del self._sigma_0
+                        del self._dlnsdlnm
+                        del self.dndm
+                    elif key is 'H0':
+                        del self._power_0
+
+                    self._transfer_cosmo.update({key:val})
+                    del self.cosmo_params
+                    del self.camb_params
 
-                if key is 'omegab':
-                    del self._power_cdm_0
-                    del self._sigma_0
-                    del self._dlnsdlnm
-                    del self.dndm
-                elif key is 'omegac':
-                    del self._power_cdm_0
-                    del self._power_0
-                    del self._sigma_0
-                    del self._dlnsdlnm
-                    del self.dndm
-                elif key is 'H0':
-                    del self._power_0
 
             elif key in self._extra_cosmo:
-                self._extra_cosmo.update({key:val})
-                del self.cosmo_params
-                if key is 'n':
-                    del self._unnormalized_power
-                elif key is 'sigma_8':
-                    del self._power_cdm_0
-                elif key is 'crit_dens':
-                    del self._power_cdm_0
-                    del self._sigma_0
-                    del self._dlnsdlnm
-                    del self.dndm
-                elif key is 'delta_c':
-                    del self.fsigma
+                if self._extra_cosmo[key] != val:
+                    if key is 'n':
+                        del self._unnormalized_power
+                    elif key is 'sigma_8':
+
+                        del self._power_cdm_0
+                    elif key is 'crit_dens':
+                        del self._power_cdm_0
+                        del self._sigma_0
+                        del self._dlnsdlnm
+                        del self.dndm
+                    elif key is 'delta_c':
+                        del self.fsigma
+
+                    self._extra_cosmo.update({key:val})
+                    del self.cosmo_params
+
+
             elif key in self._transfer_options:
-                self._transfer_options.update({key:val})
-                del self.camb_params
+                if self._transfer_options[key] != val:
+                    self._transfer_options.update({key:val})
+                    del self.camb_params
 
             elif key is 'M':
-                self.M = kwargs['M']
+                if np.any(self.M != kwargs["M"]):
+                    self.M = kwargs['M']
             elif key is "mf_fit":
-                self.mf_fit = kwargs["mf_fit"]
+                if self.mf_fit != kwargs["mf_fit"]:
+                    self.mf_fit = kwargs["mf_fit"]
             elif key is "k_bounds":
-                self.k_bounds = kwargs['k_bounds']
+                if self.k_bounds[0] != kwargs["k_bounds"][0] or self.k_bounds[1] != kwargs["k_bounds"][1]:
+                    self.k_bounds = kwargs['k_bounds']
             elif key is "transfer_file":
-                self._transfer_file = kwargs['transfer_file']
+                if self._transfer_file != kwargs['transfer_file']:
+                    self._transfer_file = kwargs['transfer_file']
             elif key is 'z':
-                self.z = kwargs['z']
+                if self.z != kwargs['z']:
+                    self.z = kwargs['z']
             elif key is "wdm_mass":
-                self.wdm_mass = kwargs['wdm_mass']
+                if self.wdm_mass != kwargs["wdm_mass"]:
+                    self.wdm_mass = kwargs['wdm_mass']
             elif key is 'delta_halo':
-                self._delta_halo_base = kwargs['delta_halo']
+                if self._delta_halo_base != kwargs['delta_halo']:
+                    self._delta_halo_base = kwargs['delta_halo']
             elif key is 'delta_wrt':
-                self.delta_wrt = kwargs['delta_wrt']
+                if self.delta_wrt != kwargs['delta_wrt']:
+                    self.delta_wrt = kwargs['delta_wrt']
             elif key is "user_fit":
-                self.user_fit = kwargs['user_fit']
+                if self.user_fit != kwargs['user_fit']:
+                    self.user_fit = kwargs['user_fit']
             elif key is "transfer_fit":
-                self.transfer_fit = kwargs['transfer_fit']
+                if self.transfer_fit != kwargs['transfer_fit']:
+                    self.transfer_fit = kwargs['transfer_fit']
             elif key is "cut_fit":
-                self.cut_fit = kwargs['cut_fit']
-            elif key is "R":
-                self.R = kwargs['R']
+                if self.cut_fit != kwargs['cut_fit']:
+                    self.cut_fit = kwargs['cut_fit']
+            elif key is "z2":  #must be set after z for comparison
+                if self.z2 != kwargs['z2']:
+                    self.z2 = kwargs["z2"]
+            elif key is "nz":
+                if self.nz != kwargs['nz']:
+                    self.nz = kwargs["nz"]
 
             else:
                 print "WARNING: ", key, " is not a valid parameter for the Perturbations class"
@@ -309,12 +350,8 @@ class Perturbations(object):
 
     @property
     def cosmo_params(self):
-        """
-        All the cosmological parameters
-        """
+        """All the cosmological parameters"""
         try:
-            #If it is defined already, just return it.
-            #Whenever a parameter is modified, the dictionary is deleted and so will be remade here
             return self.__cosmo_params
         except:
             #Piece together the cosmo dictionaries
@@ -323,7 +360,8 @@ class Perturbations(object):
             #Set some derivative parameters
             self.__cosmo_params['omegam'] = self.__cosmo_params['omegab'] + self.__cosmo_params['omegac']
             self.__cosmo_params['omegak'] = 1 - self.__cosmo_params['omegam'] - self.__cosmo_params['omegav'] - self.__cosmo_params['omegan']
-            self.__cosmo_params['mean_dens'] = self.__cosmo_params['omegam'] * 27.755 * 10 ** 10
+            self.__cosmo_params['crit_dens'] = 2.7755E11  #* self.__cosmo_params["H0"] ** 2
+            self.__cosmo_params['mean_dens'] = self.__cosmo_params['omegam'] * self.__cosmo_params['crit_dens']  #FIXME redshift evolution?
             if self._transfer_options['reion__use_optical_depth']:
                 del self.__cosmo_params['reion__redshift']
             else:
@@ -338,13 +376,9 @@ class Perturbations(object):
             pass
     @property
     def camb_params(self):
-        """
-        Here we track the camb parameters
-        """
+        """Every parameter that is passed to camb"""
 
         try:
-            #If it is defined already, just return it.
-            #Whenever a parameter is modified, the dictionary is deleted and so will be remade here
             return self.__camb_params
         except:
             #Piece together the cosmo dictionaries
@@ -540,6 +574,48 @@ class Perturbations(object):
         del self.growth
         self.__z = val
 
+    @property
+    def z2(self):
+        """ Upper redshift for survey volume weighting """
+        return self.__z2
+
+    @z2.setter
+    def z2(self, val):
+        if val is None:
+            self.__z2 = val
+            return
+
+        try:
+            val = float(val)
+        except ValueError:
+            raise ValueError("z must be a number (", val, ")")
+
+        if val <= self.z:
+            raise ValueError("z2 must be larger than z")
+        else:
+            self.__z2 = val
+
+    @property
+    def nz(self):
+        """ Number of redshift bins (if using survey volume weighting) """
+        return self.__nz
+
+    @nz.setter
+    def nz(self, val):
+        if val is None:
+            self.__nz = val
+            return
+
+        try:
+            val = int(val)
+        except ValueError:
+            raise ValueError("nz must be an integer")
+
+        if val < 1:
+            raise ValueError("nz must be >= 1")
+        else:
+            self.__nz = val
+
     @property
     def _transfer_file(self):
         """
@@ -675,21 +751,21 @@ class Perturbations(object):
             pass
 
     @property
-    def lnk(self):
+    def lnkh(self):
         """
-        The logarithmic bins in k-space
+        The logarithmic bins in k-space - this is k/h (ie h/Mpc)
         """
         try:
-            return self.__lnk
+            return self.__lnkh
         except:
             if self.transfer_fit == "CAMB":
-                self.__lnk, dlnk = tools.new_k_grid(self._transfer_original[0, :], self.k_bounds)
+                self.__lnkh, dlnk = tools.new_k_grid(self._transfer_original[0, :], self.k_bounds)
             elif self.transfer_fit == "EH":
-                self.__lnk = self._transfer_original[0, :]
+                self.__lnkh = self._transfer_original[0, :]
 
             # CHECK KR_BOUNDS
             self.max_error, self.min_error = tools.check_kr(self.M[0], self.M[-1], self.cosmo_params['mean_dens'],
-                                                            np.exp(self.__lnk[0]), np.exp(self.__lnk[-1]))
+                                                            np.exp(self.__lnkh[0]), np.exp(self.__lnkh[-1]))
 
             if self.max_error:
                 print self.max_error
@@ -697,18 +773,35 @@ class Perturbations(object):
                 print self.min_error
 
 
-            return self.__lnk
+            return self.__lnkh
 
-    @lnk.deleter
-    def lnk(self):
+    @lnkh.deleter
+    def lnkh(self):
         try:
-            del self.__lnk
+            del self.__lnkh
 
             del self._unnormalized_power
             del self._power_cdm_0
             del self._power_0
             del self._sigma_0
             del self._dlnsdlnm
+            del self.lnk
+        except:
+            pass
+
+    @property
+    def lnk(self):
+        """ Logarithmic k-bins. This is NOT k/h, just k (ie. 1/Mpc)"""
+        try:
+            return self.__lnk
+        except:
+            self.__lnk = self.lnkh + np.log(self.cosmo_params['H0'] / 100.0)
+            return self.__lnk
+
+    @lnk.deleter
+    def lnk(self):
+        try:
+            del self.__lnk
         except:
             pass
 
@@ -722,9 +815,9 @@ class Perturbations(object):
             return self.__unnormalized_power
         except:
             if self.transfer_fit == "CAMB":
-                self.__unnormalized_power = self.cosmo_params['n'] * self.lnk + 2.0 * self._transfer_function_callable(self.lnk) + np.log(2 * np.pi ** 2)
+                self.__unnormalized_power = self.cosmo_params['n'] * self.lnkh + 2.0 * self._transfer_function_callable(self.lnkh) + np.log(2 * np.pi ** 2)
             else:
-                self.__unnormalized_power = self.cosmo_params['n'] * self.lnk + 2.0 * self._transfer_original[1, :] + np.log(2 * np.pi ** 2)
+                self.__unnormalized_power = self.cosmo_params['n'] * self.lnkh + 2.0 * self._transfer_original[1, :] + np.log(2 * np.pi ** 2)
             return self.__unnormalized_power
     @_unnormalized_power.deleter
     def _unnormalized_power(self):
@@ -744,7 +837,7 @@ class Perturbations(object):
             return self.__power_cdm_0
         except:
             self.__power_cdm_0, self._normalization = tools.normalize(self.cosmo_params['sigma_8'], self._unnormalized_power,
-                                                                self.lnk, self.cosmo_params['mean_dens'])
+                                                                self.lnkh, self.cosmo_params['mean_dens'])
             return self.__power_cdm_0
 
     @_power_cdm_0.deleter
@@ -765,7 +858,7 @@ class Perturbations(object):
         except:
             if self.wdm_mass is not None:
                 print "Doing wdm with mass = ", self.wdm_mass
-                self.__power_0 = tools.wdm_transfer(self.wdm_mass, self._power_cdm_0, self.lnk,
+                self.__power_0 = tools.wdm_transfer(self.wdm_mass, self._power_cdm_0, self.lnkh,
                                                     self.cosmo_params["H0"], self.cosmo_params['omegac'])
             else:
                 self.__power_0 = self._power_cdm_0
@@ -791,7 +884,7 @@ class Perturbations(object):
         try:
             return self.__sigma_0
         except:
-            self.__sigma_0 = tools.mass_variance(self.M, self._power_0, self.lnk, self.cosmo_params['mean_dens'])
+            self.__sigma_0 = tools.mass_variance(self.M, self._power_0, self.lnkh, self.cosmo_params['mean_dens'])
             return self.__sigma_0
 
     @_sigma_0.deleter
@@ -811,7 +904,7 @@ class Perturbations(object):
         try:
             return self.__dlnsdlnm
         except:
-            self.__dlnsdlnm = tools.dlnsdlnm(self.M, self._sigma_0, self._power_0, self.lnk, self.cosmo_params['mean_dens'])
+            self.__dlnsdlnm = tools.dlnsdlnm(self.M, self._sigma_0, self._power_0, self.lnkh, self.cosmo_params['mean_dens'])
             return self.__dlnsdlnm
 
     @_dlnsdlnm.deleter
@@ -929,9 +1022,17 @@ class Perturbations(object):
         try:
             return self.__fsigma
         except:
-            fits_class = fits(self.M, self.n_eff, self.mf_fit, self.sigma, self.cosmo_params['delta_c'], self.z, self.delta_halo, self.cosmo_params, self.user_fit, self.cut_fit)
+            fits_class = fits(self.M, self.n_eff, self.mf_fit, self.sigma, self.cosmo_params['delta_c'],
+                              self.z, self.delta_halo, self.cosmo_params, self.user_fit, self.cut_fit)
             nufnu = fits_class.nufnu()
             self.__fsigma = nufnu()
+            if np.sum(np.isnan(self.__fsigma)) > 0.8 * len(self.__fsigma):
+                #the input mass range is almost completely outside the cut
+                self.massrange_error = "The specified mass-range is almost entirely outside of the limits from the fit. Setting cut_fit to False..."
+                self.cut_fit = False
+                fits_class.cut_fit = False
+                nufnu = fits_class.nufnu()
+                self.__fsigma = nufnu()
             return self.__fsigma
     @fsigma.deleter
     def fsigma(self):
@@ -949,15 +1050,50 @@ class Perturbations(object):
         try:
             return self.__dndm
         except:
-            self.__dndm = self.fsigma * self.cosmo_params['mean_dens'] * np.abs(self._dlnsdlnm) / self.M ** 2
-            if self.mf_fit == 'Behroozi':
-                a = 1 / (1 + self.z)
-                theta = 0.144 / (1 + np.exp(14.79 * (a - 0.213))) * (self.M / 10 ** 11.5) ** (0.5 / (1 + np.exp(6.5 * a)))
-                ngtm_tinker = self._ngtm()
-                ngtm_behroozi = 10 ** (theta + np.log10(ngtm_tinker))
-                dthetadM = 0.144 / (1 + np.exp(14.79 * (a - 0.213))) * (0.5 / (1 + np.exp(6.5 * a))) * (self.M / 10 ** 11.5) ** (0.5 / (1 + np.exp(6.5 * a)) - 1) / (10 ** 11.5)
-                self.__dndm = self.__dndm * 10 ** theta - ngtm_behroozi * np.log(10) * dthetadM
+            if self.z2 is None:  ##This is normally the case
+                self.__dndm = self.fsigma * self.cosmo_params['mean_dens'] * np.abs(self._dlnsdlnm) / self.M ** 2
+                if self.mf_fit == 'Behroozi':
+                    a = 1 / (1 + self.z)
+                    theta = 0.144 / (1 + np.exp(14.79 * (a - 0.213))) * (self.M / 10 ** 11.5) ** (0.5 / (1 + np.exp(6.5 * a)))
+                    ngtm_tinker = self._ngtm()
+                    ngtm_behroozi = 10 ** (theta + np.log10(ngtm_tinker))
+                    dthetadM = 0.144 / (1 + np.exp(14.79 * (a - 0.213))) * (0.5 / (1 + np.exp(6.5 * a))) * (self.M / 10 ** 11.5) ** (0.5 / (1 + np.exp(6.5 * a)) - 1) / (10 ** 11.5)
+                    self.__dndm = self.__dndm * 10 ** theta - ngtm_behroozi * np.log(10) * dthetadM
+            else:  ##This is for a survey-volume weighted calculation
+                if self.nz is None:
+                    self.nz = 10
+                zedges = np.linspace(self.z, self.z2, self.nz)
+                zcentres = (zedges[:-1] + zedges[1:]) / 2
+                dndm = np.zeros_like(zcentres)
+                vol = np.zeros_like(zedges)
+                vol[0] = cd.comoving_volume(self.z,
+                                            h=self.cosmo_params['H0'] / 100,
+                                            omega_M_0=self.cosmo_params["omegam"],
+                                            omega_b_0=self.cosmo_params["omegab"],
+                                            omega_lambda_0=self.cosmo_params['omegav'],
+                                            )
+                for i, zz in enumerate(zcentres):
+                    self.update(z=zz)
+                    dndm[i] = self.fsigma * self.cosmo_params['mean_dens'] * np.abs(self._dlnsdlnm) / self.M ** 2
+                    if self.mf_fit == 'Behroozi':
+                        a = 1 / (1 + self.z)
+                        theta = 0.144 / (1 + np.exp(14.79 * (a - 0.213))) * (self.M / 10 ** 11.5) ** (0.5 / (1 + np.exp(6.5 * a)))
+                        ngtm_tinker = self._ngtm()
+                        ngtm_behroozi = 10 ** (theta + np.log10(ngtm_tinker))
+                        dthetadM = 0.144 / (1 + np.exp(14.79 * (a - 0.213))) * (0.5 / (1 + np.exp(6.5 * a))) * (self.M / 10 ** 11.5) ** (0.5 / (1 + np.exp(6.5 * a)) - 1) / (10 ** 11.5)
+                        dndm[i] = dndm[i] * 10 ** theta - ngtm_behroozi * np.log(10) * dthetadM
 
+                    vol[i + 1] = cd.comoving_volume(z=zedges[i + 1], h=self.cosmo_params['H0'] / 100,
+                                                omega_M_0=self.cosmo_params["omegam"],
+                                                omega_b_0=self.cosmo_params["omegab"],
+                                                omega_lambda_0=self.cosmo_params['omegav'],
+                                                )
+
+                vol = vol[1:] - vol[:-1]  #Volume in shells
+                integrand = vol * dndm
+                numerator = intg.simps(integrand, x=zcentres)
+                denom = intg.simps(vol, zcentres)
+                self.__dndm = numerator / denom
             return self.__dndm
 
     @dndm.deleter
@@ -1020,9 +1156,9 @@ class Perturbations(object):
             mf = mf_func(m_upper)
         else:
             #We try to calculate the hmf as far as we can normally
-            sigma_0 = tools.mass_variance(np.exp(m_upper), self._power_0, self.lnk, self.cosmo_params['mean_dens'])
+            sigma_0 = tools.mass_variance(np.exp(m_upper), self._power_0, self.lnkh, self.cosmo_params['mean_dens'])
             sigma = sigma_0 * self.growth
-            dlnsdlnm = tools.dlnsdlnm(np.exp(m_upper), sigma_0, self._power_0, self.lnk, self.cosmo_params['mean_dens'])
+            dlnsdlnm = tools.dlnsdlnm(np.exp(m_upper), sigma_0, self._power_0, self.lnkh, self.cosmo_params['mean_dens'])
             n_eff = tools.n_eff(dlnsdlnm)
             fsigma = fits(m_upper, n_eff, self.mf_fit, sigma, self.cosmo_params['delta_c'],
                           self.z, self.delta_halo, self.cosmo_params, self.user_fit, cut_fit=True).nufnu()()
@@ -1051,9 +1187,9 @@ class Perturbations(object):
             mf = mf_func(m_lower)
         else:
             #We try to calculate the hmf as far as we can normally
-            sigma_0 = tools.mass_variance(np.exp(m_lower), self._power_0, self.lnk, self.cosmo_params['mean_dens'])
+            sigma_0 = tools.mass_variance(np.exp(m_lower), self._power_0, self.lnkh, self.cosmo_params['mean_dens'])
             sigma = sigma_0 * self.growth
-            dlnsdlnm = tools.dlnsdlnm(np.exp(m_lower), sigma_0, self._power_0, self.lnk, self.cosmo_params['mean_dens'])
+            dlnsdlnm = tools.dlnsdlnm(np.exp(m_lower), sigma_0, self._power_0, self.lnkh, self.cosmo_params['mean_dens'])
             n_eff = tools.n_eff(dlnsdlnm)
             fsigma = fits(m_lower, n_eff, self.mf_fit, sigma, self.cosmo_params['delta_c'],
                           self.z, self.delta_halo, self.cosmo_params, self.user_fit, cut_fit=True).nufnu()()
@@ -1214,7 +1350,7 @@ class Perturbations(object):
             self.__mltm = intg.cumtrapz(mass_function * M, dx=np.log(M[1]) - np.log(M[0]), initial=0) + int_lower
 
             #We need to set ngtm back in the original length vector with nans where they were originally
-            if len(self.__nltm) < len(self.M):
+            if len(self.__mltm) < len(self.M):
                 nltm_temp = np.zeros_like(self.dndlnm)
                 nltm_temp[:] = np.nan
                 nltm_temp[np.logical_not(np.isnan(self.dndlnm))] = self.__mltm
@@ -1240,15 +1376,3 @@ class Perturbations(object):
 
 
 
-
-if __name__ == "__main__":
-    M = np.arange(10, 15, 0.01)
-    pert = Perturbations(M)
-    pert.dndlnm
-    pert.how_big
-
-    pert.update(z=1, omegac=0.2)
-    pert.dndlog10m
-
-
-
