@@ -33,10 +33,8 @@ from scipy.interpolate import InterpolatedUnivariateSpline as spline
 ###############################################################################
 def get_transfer(transfer_file, camb_dict, transfer_fit, k_bounds=None):
     """
-    A convenience function used to fully setup the workspace in the 'usual' way
-    
     We use either CAMB or the EH approximation to get the transfer function.
-    The transfer function is in terms of the wavenumber IN UNITS OF h/Mpc!!
+    The transfer function is in terms of k/h -- IN UNITS OF h/Mpc??!!
     """
     #If no transfer file uploaded, but it was custom, execute CAMB
     if transfer_file is None:
@@ -45,7 +43,7 @@ def get_transfer(transfer_file, camb_dict, transfer_fit, k_bounds=None):
             T = np.log(T[[0, 6], :, 0])
             del sig8, k
         elif transfer_fit == "EH":
-            k = np.exp(np.linspace(np.log(k_bounds[0]), np.log(k_bounds[1]), 4097))
+            k = np.exp(np.linspace(np.log(k_bounds[0]), np.log(k_bounds[1]), 250))
             #Since the function natively calculates the transfer based on k in Mpc^-1,
             # we need to multiply by h.
             t, T = pert.transfer_function_EH(k * camb_dict['H0'] / 100,
@@ -55,7 +53,7 @@ def get_transfer(transfer_file, camb_dict, transfer_fit, k_bounds=None):
             T = np.vstack((np.log(k), np.log(T)))
             del t
     else:
-        #Import the transfer file wherever it is.
+        #Import the transfer file
         T = read_transfer(transfer_file)
 
     return T
@@ -211,9 +209,10 @@ def radius_to_mass(R, mean_dens):
     Calculates mass from radius given mean density
     """
     return 4 * np.pi * R ** 3 * mean_dens / 3
+
 def wdm_transfer(m_x, power_cdm, lnk, H0, omegac):
     """
-    Tansforms the CDM Power Spectrum into a WDM power spectrum for a given warm particle mass m_x.
+    Transforms the CDM Power Spectrum into a WDM power spectrum for a given warm particle mass m_x.
     
     NOTE: formula from Bode et. al. 2001 eq. A9
     """
@@ -256,10 +255,7 @@ def n_eff(dlnsdlnm):
 
 def new_k_grid(k, k_bounds=None):
     """
-    Creates a new grid for the transfer function, for application of Romberg integration.
-    
-    Note: for Romberg integration, the number of steps must be 2**p+1 where p is an integer, which is why this scaling
-            should be performed. We choose 4097 bins for ln(k). This could possibly be optimized or made variable.
+    Creates a new grid for the transfer function.
     """
 
     # Determine the true k_bounds.
